@@ -26,11 +26,21 @@ def test_mock_builtin():
 
     assert open(__file__) != 'foobar'
 
+
+def test_mock_builtin_os():
+    print(os.open.__name__)
+    with aspectlib.weave('os.open', mock('foobar')):
+        assert os.open('???') == 'foobar'
+
+    assert os.open(__file__, 0) != 'foobar'
+
+
 def test_record_warning():
     with aspectlib.weave('warnings.warn', record):
         warnings.warn('crap')
         assert warnings.warn.calls, [(None, ('crap',) == {})]
 
+
 @pytest.mark.skipif(not hasattr(os, 'fork'), reason="os.fork not available")
 def test_fork():
     with aspectlib.weave('os.fork', mock('foobar')):
@@ -68,6 +78,23 @@ def test_socket(target=socket.socket):
 
     assert re.match(LOG_TEST_SOCKET, buf.getvalue())
 
+
 def test_socket_as_string_target():
     test_socket(target='socket.socket')
 
+
+def test_socket_meth(meth=socket.socket.close):
+    calls = []
+    with aspectlib.weave(meth, record(history=calls)):
+        s = socket.socket()
+        assert s.close() is None
+    assert calls == [(s, (), {})]
+    del calls[:]
+
+    s = socket.socket()
+    assert s.close() is None
+    assert calls == []
+
+
+def test_socket_meth_as_string_target():
+    test_socket_meth('socket.socket.close')
